Interface ArgsParserProperties

All Superinterfaces:
AnnotatorAccessor, ArgsParser, ArgsParserBuilder<ArgsParser>, ArgsProcessorBuilder<ArgsParser>, ArgsSyntaxAccessor, ArgsSyntaxAccessor.ArgsSyntaxBuilder<ArgsParser>, ArgsSyntaxAccessor.ArgsSyntaxMutator, ArgsSyntaxAccessor.ArgsSyntaxProperty, ArgumentEscapeCodeAccessor, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<ArgsParser>, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeProperty, BannerBorderEscapeCodeAccessor, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<ArgsParser>, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeProperty, BannerEscapeCodeAccessor, BannerEscapeCodeAccessor.BannerEscapeCodeBuilder<ArgsParser>, BannerEscapeCodeAccessor.BannerEscapeCodeMutator, BannerEscapeCodeAccessor.BannerEscapeCodeProperty, BannerFontAccessor, BannerFontAccessor.BannerFontBuilder<ArgsParser>, BannerFontAccessor.BannerFontMutator, BannerFontAccessor.BannerFontProperty, BannerFontPaletteAccessor, BannerFontPaletteAccessor.BannerFontPaletteBuilder<ArgsParser>, BannerFontPaletteAccessor.BannerFontPaletteMutator, BannerFontPaletteAccessor.BannerFontPaletteProperty, CliMetrics, CommandEscapeCodeAccessor, CommandEscapeCodeAccessor.CommandEscapeCodeBuilder<ArgsParser>, CommandEscapeCodeAccessor.CommandEscapeCodeMutator, CommandEscapeCodeAccessor.CommandEscapeCodeProperty, ConsoleWidthAccessor, ConsoleWidthAccessor.ConsoleWidthBuilder<ArgsParser>, ConsoleWidthAccessor.ConsoleWidthMutator, ConsoleWidthAccessor.ConsoleWidthProperty, Containable, CopyrightAccessor, CopyrightAccessor.CopyrightBuilder<ArgsParser>, CopyrightAccessor.CopyrightMutator, CopyrightAccessor.CopyrightProperty, DelimiterAccessor, DescriptionAccessor, DescriptionAccessor.DescriptionBuilder<ArgsParser>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionProperty, DescriptionEscapeCodeAccessor, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<ArgsParser>, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeProperty, Diagnosable, EmptyAccessor, EscapeCodesStatusAccessor, EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<ArgsParser>, EscapeCodesStatusAccessor.EscapeCodeStatusMutator, EscapeCodesStatusAccessor.EscapeCodeStatusProperty, ExamplesAccessor, ExamplesAccessor.ExamplesBuilder<ArgsParser>, ExamplesAccessor.ExamplesMutator, ExamplesAccessor.ExamplesProperty, ImmutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutableProperties, ImmutableTable<String,String>, Keys<String,String>, KeywordEscapeCodeAccessor, KeywordEscapeCodeAccessor.KeywordEscapeCodeBuilder<ArgsParser>, KeywordEscapeCodeAccessor.KeywordEscapeCodeMutator, KeywordEscapeCodeAccessor.KeywordEscapeCodeProperty, LicenseAccessor, LicenseAccessor.LicenseBuilder<ArgsParser>, LicenseAccessor.LicenseMutator, LicenseAccessor.LicenseProperty, LineBreakAccessor, LineBreakAccessor.LineBreakBuilder<ArgsParser>, LineBreakAccessor.LineBreakMutator, LineBreakAccessor.LineBreakProperty, LineSeparatorEscapeCodeAccessor, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<ArgsParser>, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeMutator, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeProperty, LongOptionPrefixAccessor, LongOptionPrefixAccessor.LongOptionPrefixBuilder<ArgsParser>, LongOptionPrefixAccessor.LongOptionPrefixMutator, LongOptionPrefixAccessor.LongOptionPrefixProperty, MaxConsoleWidthAccessor, MaxConsoleWidthAccessor.MaxConsoleWidthBuilder<ArgsParser>, MaxConsoleWidthAccessor.MaxConsoleWidthMutator, MaxConsoleWidthAccessor.MaxConsoleWidthProperty, NameAccessor, NameAccessor.NameBuilder<ArgsParser>, NameAccessor.NameMutator, NameAccessor.NameProperty, Optionable, Resetable, ResetEscapeCodeAccessor, ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<ArgsParser>, ResetEscapeCodeAccessor.ResetEscapeCodeMutator, ResetEscapeCodeAccessor.ResetEscapeCodeProperty, Schemable<DiagnosticOptions>, ShortOptionPrefixAccessor, ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<ArgsParser>, ShortOptionPrefixAccessor.ShortOptionPrefixMutator, ShortOptionPrefixAccessor.ShortOptionPrefixProperty, SyntaxMetricsAccessor, SyntaxMetricsAccessor.SyntaxMetricsBuilder<ArgsParser>, SyntaxMetricsAccessor.SyntaxMetricsMutator, SyntaxMetricsAccessor.SyntaxMetricsProperty, TextBoxGridAccessor, TextBoxGridAccessor.TextBoxGridBuilder<ArgsParser>, TextBoxGridAccessor.TextBoxGridMutator, TextBoxGridAccessor.TextBoxGridProperty, TitleAccessor, TitleAccessor.TitleBuilder<ArgsParser>, TitleAccessor.TitleMutator, TitleAccessor.TitleProperty, TypeAccessor<String>
All Known Implementing Classes:
CliArgsParserProperties

public interface ArgsParserProperties extends ImmutableProperties, ArgsParser
The ArgsParserProperties represent ImmutableProperties generated from command line arguments being parsed by a command line syntax as of the definition for the ArgsParser.
  • Method Details

    • evalArgs

      Operand<?>[] evalArgs(String[] aArgs) throws ArgsSyntaxException
      Evaluates the command line arguments and sets the identified properties in this ImmutableProperties instance. Previously identified properties are reset upon invocation of this method. When provided, then an Operand's alias is used as property name, else as fall back, the operand's (when being of sub-type Option) long-option or short-option is used. Make sure, to provide an alias to make the ImmutableProperties work and feel as intended!
      Specified by:
      evalArgs in interface ArgsParser
      Throws:
      ArgsSyntaxException
    • evalArgs

      Operand<?>[] evalArgs(List<String> aArgs) throws ArgsSyntaxException
      Evaluates the command line arguments and sets the identified properties in this ImmutableProperties instance. Previously identified properties are reset upon invocation of this method. When provided, then an Operand's alias is used as property name, else as fall back, the operand's (when being of sub-type Option) long-option or short-option is used. Make sure, to provide an alias to make the ImmutableProperties work and feel as intended!
      Specified by:
      evalArgs in interface ArgsParser
      Throws:
      ArgsSyntaxException
    • evalArgs

      Operand<?>[] evalArgs(String aToPath, List<String> aArgs) throws ArgsSyntaxException
      Same as evalArgs(String[]) with the difference that the identified properties are inserted below the provided path.
      Parameters:
      aToPath - The path below which to insert the identified properties.
      aArgs - The command line arguments to be evaluated.
      Returns:
      The list of evaluated command line arguments being instances of the Operand interfaces or its sub-types.
      Throws:
      ArgsSyntaxException - thrown in case of a command line arguments mismatch regarding provided and expected args.
    • evalArgs

      Operand<?>[] evalArgs(String aToPath, String[] aArgs) throws ArgsSyntaxException
      Same as evalArgs(String[]) with the difference that the identified properties are inserted below the provided path.
      Parameters:
      aToPath - The path below which to insert the identified properties.
      aArgs - The command line arguments to be evaluated.
      Returns:
      The list of evaluated command line arguments being instances of the Operand interfaces or its sub-types.
      Throws:
      ArgsSyntaxException - thrown in case of a command line arguments mismatch regarding provided and expected args.
    • withEvalArgs

      default ArgsParserProperties withEvalArgs(String[] aArgs) throws ArgsSyntaxException
      Same as evalArgs(String[]) with the difference that this class's instance being invoked is returned as of the builder pattern.
      Specified by:
      withEvalArgs in interface ArgsParser
      Specified by:
      withEvalArgs in interface ArgsParserBuilder<ArgsParser>
      Parameters:
      aArgs - The command line arguments to be evaluated.
      Returns:
      This invoked instance as of the builder pattern to chain method calls.
      Throws:
      ArgsSyntaxException - thrown in case of a command line arguments mismatch regarding provided and expected args.
    • withEvalArgs

      default ArgsParserProperties withEvalArgs(List<String> aArgs) throws ArgsSyntaxException
      Same as evalArgs(List) with the difference that this class's instance being invoked is returned as of the builder pattern.
      Specified by:
      withEvalArgs in interface ArgsParser
      Specified by:
      withEvalArgs in interface ArgsParserBuilder<ArgsParser>
      Parameters:
      aArgs - The command line arguments to be evaluated.
      Returns:
      This invoked instance as of the builder pattern to chain method calls.
      Throws:
      ArgsSyntaxException - thrown in case of a command line arguments mismatch regarding provided and expected args.
    • withEvalArgs

      default ArgsParserProperties withEvalArgs(String aToPath, List<String> aArgs) throws ArgsSyntaxException
      Same as evalArgs(String[]) with the difference that the identified properties are inserted below the provided path and that this class's instance being invoked is returned as of the builder pattern.
      Parameters:
      aToPath - The path below which to insert the identified properties.
      aArgs - The command line arguments to be evaluated.
      Returns:
      This invoked instance as of the builder pattern to chain method calls.
      Throws:
      ArgsSyntaxException - thrown in case of a command line arguments mismatch regarding provided and expected args.
    • withEvalArgs

      default ArgsParserProperties withEvalArgs(String aToPath, String[] aArgs) throws ArgsSyntaxException
      Same as evalArgs(String[]) with the difference that the identified properties are inserted below the provided path and that this class's instance being invoked is returned as of the builder pattern.
      Parameters:
      aToPath - The path below which to insert the identified properties.
      aArgs - The command line arguments to be evaluated.
      Returns:
      This invoked instance as of the builder pattern to chain method calls.
      Throws:
      ArgsSyntaxException - thrown in case of a command line arguments mismatch regarding provided and expected args.