Package org.refcodes.properties.ext.cli
Class ArgsParserPropertiesImpl
- java.lang.Object
-
- org.refcodes.cli.ArgsParserImpl
-
- org.refcodes.properties.ext.cli.ArgsParserPropertiesImpl
-
- All Implemented Interfaces:
org.refcodes.cli.ArgsParser,org.refcodes.cli.ArgsParserMixin<org.refcodes.cli.ArgsParser>,org.refcodes.cli.RootConditionAccessor,org.refcodes.component.Resetable,org.refcodes.mixin.AnnotatorAccessor,org.refcodes.mixin.DelimiterAccessor,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<org.refcodes.cli.ArgsParser>,org.refcodes.mixin.DescriptionAccessor.DescriptionMutator,org.refcodes.mixin.DescriptionAccessor.DescriptionProperty,org.refcodes.mixin.Dumpable,org.refcodes.mixin.EmptyAccessor,org.refcodes.mixin.EscapeCodesStatusAccessor,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<org.refcodes.cli.ArgsParser>,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty,org.refcodes.mixin.NameAccessor,org.refcodes.mixin.NameAccessor.NameBuilder<org.refcodes.cli.ArgsParser>,org.refcodes.mixin.NameAccessor.NameMutator,org.refcodes.mixin.NameAccessor.NameProperty,org.refcodes.mixin.ResetEscapeCodeAccessor,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<org.refcodes.cli.ArgsParser>,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty,org.refcodes.mixin.TitleAccessor,org.refcodes.mixin.TitleAccessor.TitleBuilder<org.refcodes.cli.ArgsParser>,org.refcodes.mixin.TitleAccessor.TitleMutator,org.refcodes.mixin.TitleAccessor.TitleProperty,org.refcodes.mixin.TypeAccessor<String>,ArgsParserProperties,org.refcodes.properties.Properties,org.refcodes.struct.CanonicalMap,org.refcodes.struct.Containable,org.refcodes.struct.Dictionary<String,String>,org.refcodes.struct.InterOperableMap<String>,org.refcodes.struct.Keys<String,String>,org.refcodes.struct.PathMap<String>,org.refcodes.textual.TextBoxGridAccessor,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<org.refcodes.cli.ArgsParser>,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridProperty
public class ArgsParserPropertiesImpl extends org.refcodes.cli.ArgsParserImpl implements ArgsParserProperties
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AnnotatorAccessor
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.CanonicalMap
org.refcodes.struct.CanonicalMap.CanonicalMapBuilder, org.refcodes.struct.CanonicalMap.MutableCanonicalMap
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.DelimiterAccessor
org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary
org.refcodes.struct.Dictionary.MutableDictionary<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor
org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<B extends org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<B>>, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.InterOperableMap
org.refcodes.struct.InterOperableMap.InterOperableMapBuilder<T extends Object>, org.refcodes.struct.InterOperableMap.MutableInterOperableMap<T extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
org.refcodes.struct.Keys.MutableKeys<K extends Object,V extends Object>, org.refcodes.struct.Keys.MutableValues<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.NameAccessor
org.refcodes.mixin.NameAccessor.NameBuilder<B extends org.refcodes.mixin.NameAccessor.NameBuilder<B>>, org.refcodes.mixin.NameAccessor.NameMutator, org.refcodes.mixin.NameAccessor.NameProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.PathMap
org.refcodes.struct.PathMap.MutablePathMap<T extends Object>, org.refcodes.struct.PathMap.PathMapBuilder<T extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.properties.Properties
org.refcodes.properties.Properties.MutableProperties, org.refcodes.properties.Properties.PropertiesBuilder
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor
org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<B extends org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<B>>, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty
-
Nested classes/interfaces inherited from interface org.refcodes.cli.RootConditionAccessor
org.refcodes.cli.RootConditionAccessor.RootConditionBuilder<B extends org.refcodes.cli.RootConditionAccessor.RootConditionBuilder<B>>, org.refcodes.cli.RootConditionAccessor.RootConditionMutator, org.refcodes.cli.RootConditionAccessor.RootConditionProperty
-
Nested classes/interfaces inherited from interface org.refcodes.textual.TextBoxGridAccessor
org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<B extends org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<?>>, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.TitleAccessor
org.refcodes.mixin.TitleAccessor.TitleBuilder<B extends org.refcodes.mixin.TitleAccessor.TitleBuilder<B>>, org.refcodes.mixin.TitleAccessor.TitleMutator, org.refcodes.mixin.TitleAccessor.TitleProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>
-
-
Constructor Summary
Constructors Constructor Description ArgsParserPropertiesImpl()Constructs theArgsParserPropertiesinstance with no syntax notation (no rootArgsSyntax).ArgsParserPropertiesImpl(String[] aArgs)Constructs theArgsParserPropertiesinstance with the given arguments and the defaultSyntaxNotation.REFCODES.ArgsParserPropertiesImpl(String[] aArgs, org.refcodes.cli.ArgsSyntax aRootArgsSyntax)Constructs theArgsParserPropertiesinstance with the given rootArgsSyntaxand the defaultSyntaxNotation.REFCODES.ArgsParserPropertiesImpl(String[] aArgs, org.refcodes.cli.Option<?> aRootOption)Constructs theArgsParserPropertiesinstance with the given rootOptionand the defaultSyntaxNotation.REFCODES.ArgsParserPropertiesImpl(org.refcodes.cli.ArgsSyntax aRootArgsSyntax)Constructs theArgsParserPropertiesinstance with the given rootArgsSyntaxand the defaultSyntaxNotation.REFCODES.ArgsParserPropertiesImpl(org.refcodes.cli.Option<?> aRootOption)Constructs theArgsParserPropertiesinstance with the given rootOptionand the defaultSyntaxNotation.REFCODES.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleancontainsKey(Object aKey)List<? extends org.refcodes.cli.Operand<?>>evalArgs(String[] aArgs)Evaluates the command line arguments and sets the identified properties in thisPropertiesinstance.List<? extends org.refcodes.cli.Operand<?>>evalArgs(String aToPath, String[] aArgs)Same asArgsParserProperties.evalArgs(String[])with the difference that the identified properties are inserted below the provided path.List<? extends org.refcodes.cli.Operand<?>>evalArgs(String aToPath, List<String> aArgs)Same asArgsParserProperties.evalArgs(String[])with the difference that the identified properties are inserted below the provided path.List<? extends org.refcodes.cli.Operand<?>>evalArgs(List<String> aArgs)Evaluates the command line arguments and sets the identified properties in thisPropertiesinstance.Stringget(Object aKey)chargetAnnotator()chargetDelimiter()booleanisEmpty()Set<String>keySet()org.refcodes.properties.PropertiesretrieveFrom(String aFromPath)org.refcodes.properties.PropertiesretrieveTo(String aToPath)intsize()ObjecttoDataStructure(String aPath)Collection<String>values()-
Methods inherited from class org.refcodes.cli.ArgsParserImpl
addExample, errorLn, fromArgs, getArgsSyntax, getBannerBorderEscapeCode, getBannerEscapeCode, getCommandEscapeCode, getCopyrightNote, getDescription, getDescriptionEscapeCode, getExamples, getLicenseNote, getLineSeparatorEscapeCode, getName, getOptionEscapeCode, getParamEscapeCode, getResetEscapeCode, getSeparatorLnChar, getTextBoxGrid, getTitle, isEscapeCodesEnabled, printBanner, printCopyrightNote, printDescription, printExamples, printLicenseNote, printLn, printLn, printOptions, printSeparatorLn, printSynopsis, reset, setBannerBorderEscapeCode, setBannerEscapeCode, setBannerFont, setBannerFontPalette, setCommandEscapeCode, setConsoleWidth, setCopyrightNote, setDescription, setDescriptionEscapeCode, setErrorOut, setEscapeCodesEnabled, setLicenseNote, setLineBreak, setLineSeparatorEscapeCode, setMaxConsoleWidth, setName, setOptionEscapeCode, setParamEscapeCode, setResetEscapeCode, setSeparatorLnChar, setStandardOut, setSyntaxNotation, setTextBoxGrid, setTitle
-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.refcodes.cli.ArgsParser
addExample, addExample, errorLn, getArgsSyntax, getBannerBorderEscapeCode, getBannerEscapeCode, getCommandEscapeCode, getCopyrightNote, getDescription, getDescriptionEscapeCode, getExamples, getLicenseNote, getLineSeparatorEscapeCode, getOptionEscapeCode, getParamEscapeCode, getSeparatorLnChar, printBanner, printBody, printCopyrightNote, printDescription, printExamples, printHelp, printLicenseNote, printLn, printLn, printOptions, printSeparatorLn, printSynopsis, setBannerBorderEscapeCode, setBannerEscapeCode, setBannerFont, setBannerFontPalette, setCommandEscapeCode, setConsoleWidth, setCopyrightNote, setDescriptionEscapeCode, setErrorOut, setLicenseNote, setLineBreak, setLineSeparatorEscapeCode, setMaxConsoleWidth, setOptionEscapeCode, setParamEscapeCode, setSeparatorLnChar, setStandardOut, setSyntaxNotation, withBannerBorderEscapeCode, withBannerEscapeCode, withBannerFont, withBannerFontPalette, withCommandEscapeCode, withConsoleWidth, withCopyrightNote, withDescription, withDescriptionEscapeCode, withErrorOut, withEscapeCodesEnabled, withExample, withExample, withExamples, withExamples, withLicenseNote, withLineBreak, withLineSeparatorEscapeCode, withMaxConsoleWidth, withName, withOptionEscapeCode, withParamEscapeCode, withResetEscapeCode, withSeparatorLnChar, withStandardOut, withSyntaxNotation, withTextBoxGrid, withTitle
-
Methods inherited from interface org.refcodes.properties.ext.cli.ArgsParserProperties
withEvalArgs, withEvalArgs, withEvalArgs, withEvalArgs
-
Methods inherited from interface org.refcodes.struct.CanonicalMap
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, queryBetween, toMap, toProperties
-
Methods inherited from interface org.refcodes.mixin.DescriptionAccessor.DescriptionMutator
setDescription
-
Methods inherited from interface org.refcodes.mixin.DescriptionAccessor.DescriptionProperty
letDescription
-
Methods inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator
setEscapeCodesEnabled
-
Methods inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty
letEscapeCodesEnabled
-
Methods inherited from interface org.refcodes.struct.InterOperableMap
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOr
-
Methods inherited from interface org.refcodes.struct.PathMap
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toType
-
Methods inherited from interface org.refcodes.properties.Properties
containsValue, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, getType, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo
-
Methods inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator
setResetEscapeCode
-
Methods inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty
letResetEscapeCode
-
Methods inherited from interface org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator
setTextBoxGrid
-
-
-
-
Constructor Detail
-
ArgsParserPropertiesImpl
public ArgsParserPropertiesImpl()
Constructs theArgsParserPropertiesinstance with no syntax notation (no rootArgsSyntax). As no syntax notation is required by the constructor (no rootArgsSyntax), no syntax validation is done byevalArgs(String[])and the like methods. When no syntax validation is fine for you, you can directly go for the constructorArgsParserPropertiesImpl(String[]).
-
ArgsParserPropertiesImpl
public ArgsParserPropertiesImpl(org.refcodes.cli.ArgsSyntax aRootArgsSyntax)
Constructs theArgsParserPropertiesinstance with the given rootArgsSyntaxand the defaultSyntaxNotation.REFCODES.- Parameters:
aRootArgsSyntax- The root condition being the node from which parsing the command line arguments starts.
-
ArgsParserPropertiesImpl
public ArgsParserPropertiesImpl(org.refcodes.cli.Option<?> aRootOption)
Constructs theArgsParserPropertiesinstance with the given rootOptionand the defaultSyntaxNotation.REFCODES.- Parameters:
aRootOption- The root option being the node from which parsing the command line arguments starts.
-
ArgsParserPropertiesImpl
public ArgsParserPropertiesImpl(String[] aArgs)
Constructs theArgsParserPropertiesinstance with the given arguments and the defaultSyntaxNotation.REFCODES. As no syntax notation is required by the constructor (no rootArgsSyntax), no syntax validation is done. Therefore the properties are heuristically determined from the provided command line arguments.- Parameters:
aArgs- The command line arguments to be evaluated.
-
ArgsParserPropertiesImpl
public ArgsParserPropertiesImpl(String[] aArgs, org.refcodes.cli.ArgsSyntax aRootArgsSyntax) throws org.refcodes.cli.ArgsSyntaxException
Constructs theArgsParserPropertiesinstance with the given rootArgsSyntaxand the defaultSyntaxNotation.REFCODES.- Parameters:
aArgs- The command line arguments to be evaluated.aRootArgsSyntax- The root condition being the node from which parsing the command line arguments starts.- Throws:
org.refcodes.cli.ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
ArgsParserPropertiesImpl
public ArgsParserPropertiesImpl(String[] aArgs, org.refcodes.cli.Option<?> aRootOption) throws org.refcodes.cli.ArgsSyntaxException
Constructs theArgsParserPropertiesinstance with the given rootOptionand the defaultSyntaxNotation.REFCODES.- Parameters:
aArgs- The command line arguments to be evaluated.aRootOption- The root option being the node from which parsing the command line arguments starts.- Throws:
org.refcodes.cli.ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
-
Method Detail
-
evalArgs
public List<? extends org.refcodes.cli.Operand<?>> evalArgs(String[] aArgs) throws org.refcodes.cli.ArgsSyntaxException
Evaluates the command line arguments and sets the identified properties in thisPropertiesinstance. Previously identified properties are reset upon invocation of this method. When provided, then anOperand's alias is used as property name, else as fall back, the operand's (when being of sub-typeOption) long-option or short-option is used. Make sure, to provide an alias to make thePropertieswork and feel as intended!- Specified by:
evalArgsin interfaceorg.refcodes.cli.ArgsParser- Specified by:
evalArgsin interfaceArgsParserProperties- Overrides:
evalArgsin classorg.refcodes.cli.ArgsParserImpl- Throws:
org.refcodes.cli.ArgsSyntaxException
-
evalArgs
public List<? extends org.refcodes.cli.Operand<?>> evalArgs(List<String> aArgs) throws org.refcodes.cli.ArgsSyntaxException
Evaluates the command line arguments and sets the identified properties in thisPropertiesinstance. Previously identified properties are reset upon invocation of this method. When provided, then anOperand's alias is used as property name, else as fall back, the operand's (when being of sub-typeOption) long-option or short-option is used. Make sure, to provide an alias to make thePropertieswork and feel as intended!- Specified by:
evalArgsin interfaceorg.refcodes.cli.ArgsParser- Specified by:
evalArgsin interfaceArgsParserProperties- Throws:
org.refcodes.cli.ArgsSyntaxException
-
evalArgs
public List<? extends org.refcodes.cli.Operand<?>> evalArgs(String aToPath, List<String> aArgs) throws org.refcodes.cli.ArgsSyntaxException
Same asArgsParserProperties.evalArgs(String[])with the difference that the identified properties are inserted below the provided path.- Specified by:
evalArgsin interfaceArgsParserProperties- Parameters:
aToPath- The path below which to insert the identified properties.aArgs- The command line arguments to be evaluated.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
org.refcodes.cli.ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
getAnnotator
public char getAnnotator()
- Specified by:
getAnnotatorin interfaceorg.refcodes.mixin.AnnotatorAccessor- Specified by:
getAnnotatorin interfaceorg.refcodes.properties.Properties
-
getDelimiter
public char getDelimiter()
- Specified by:
getDelimiterin interfaceorg.refcodes.mixin.DelimiterAccessor- Specified by:
getDelimiterin interfaceorg.refcodes.properties.Properties- Overrides:
getDelimiterin classorg.refcodes.cli.ArgsParserImpl
-
size
public int size()
- Specified by:
sizein interfaceorg.refcodes.struct.Containable
-
containsKey
public boolean containsKey(Object aKey)
-
isEmpty
public boolean isEmpty()
- Specified by:
isEmptyin interfaceorg.refcodes.mixin.EmptyAccessor
-
values
public Collection<String> values()
-
retrieveFrom
public org.refcodes.properties.Properties retrieveFrom(String aFromPath)
- Specified by:
retrieveFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveFromin interfaceorg.refcodes.struct.PathMap<String>- Specified by:
retrieveFromin interfaceorg.refcodes.properties.Properties
-
retrieveTo
public org.refcodes.properties.Properties retrieveTo(String aToPath)
- Specified by:
retrieveToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveToin interfaceorg.refcodes.struct.PathMap<String>- Specified by:
retrieveToin interfaceorg.refcodes.properties.Properties
-
toDataStructure
public Object toDataStructure(String aPath)
- Specified by:
toDataStructurein interfaceorg.refcodes.struct.PathMap<String>
-
evalArgs
public List<? extends org.refcodes.cli.Operand<?>> evalArgs(String aToPath, String[] aArgs) throws org.refcodes.cli.ArgsSyntaxException
Same asArgsParserProperties.evalArgs(String[])with the difference that the identified properties are inserted below the provided path.- Specified by:
evalArgsin interfaceArgsParserProperties- Parameters:
aToPath- The path below which to insert the identified properties.aArgs- The command line arguments to be evaluated.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
org.refcodes.cli.ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
-