Package org.refcodes.properties.ext.cli
package org.refcodes.properties.ext.cli
This artifact extends the refcodes-properties
toolkit with functionality from the
refcodes-cli
toolkit, integrating command line arguments into the CliArgsParserProperties
sub-type of the ImmutableProperties
type.
Please refer to the refcodes-properties: Managing your application's configuration documentation for an up-to-date and detailed description on the usage of this artifact.
-
ClassDescriptionThe
ArgsParserPropertiesrepresentImmutablePropertiesgenerated from command line arguments being parsed by a command line syntax as of the definition for theArgsParser.Provides an accessor for aArgsParserPropertiesproperty.ArgsParserPropertiesAccessor.ArgsParserPropertiesBuilder<B extends ArgsParserPropertiesAccessor.ArgsParserPropertiesBuilder<B>>Provides a builder method for aArgsParserPropertiesproperty returning the builder for applying multiple build operations.Provides a mutator for aArgsParserPropertiesproperty.Provides aArgsParserPropertiesproperty.TheCliArgsParserPropertiesclass implements theArgsParserPropertiestype to combine theArgsParsertype with theImmutablePropertiestype in a dedicated class.