Uses of Package
org.refcodes.properties.ext.cli
-
Classes in org.refcodes.properties.ext.cli used by org.refcodes.properties.ext.cliClassDescriptionThe
ArgsParserPropertiesrepresentImmutablePropertiesgenerated from command line arguments being parsed by a command line syntax as of the definition for theArgsParser.Provides an accessor for aArgsParserPropertiesproperty.Provides a builder method for aArgsParserPropertiesproperty returning the builder for applying multiple build operations.Provides a mutator for aArgsParserPropertiesproperty.TheCliArgsParserPropertiesclass implements theArgsParserPropertiestype to combine theArgsParsertype with theImmutablePropertiestype in a dedicated class.