Interface ArgsParserProperties
- All Superinterfaces:
AnnotatorAccessor, ArgsParser, ArgsParserBuilder<ArgsParser>, ArgsProcessorBuilder<ArgsParser>, ArgsSyntaxAccessor, ArgsSyntaxAccessor.ArgsSyntaxBuilder<ArgsParser>, ArgsSyntaxAccessor.ArgsSyntaxMutator, ArgsSyntaxAccessor.ArgsSyntaxProperty, ArgumentEscapeCodeAccessor, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<ArgsParser>, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeProperty, BannerBorderEscapeCodeAccessor, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<ArgsParser>, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeProperty, BannerEscapeCodeAccessor, BannerEscapeCodeAccessor.BannerEscapeCodeBuilder<ArgsParser>, BannerEscapeCodeAccessor.BannerEscapeCodeMutator, BannerEscapeCodeAccessor.BannerEscapeCodeProperty, BannerFontAccessor, BannerFontAccessor.BannerFontBuilder<ArgsParser>, BannerFontAccessor.BannerFontMutator, BannerFontAccessor.BannerFontProperty, BannerFontPaletteAccessor, BannerFontPaletteAccessor.BannerFontPaletteBuilder<ArgsParser>, BannerFontPaletteAccessor.BannerFontPaletteMutator, BannerFontPaletteAccessor.BannerFontPaletteProperty, CliMetrics, CommandEscapeCodeAccessor, CommandEscapeCodeAccessor.CommandEscapeCodeBuilder<ArgsParser>, CommandEscapeCodeAccessor.CommandEscapeCodeMutator, CommandEscapeCodeAccessor.CommandEscapeCodeProperty, ConsoleWidthAccessor, ConsoleWidthAccessor.ConsoleWidthBuilder<ArgsParser>, ConsoleWidthAccessor.ConsoleWidthMutator, ConsoleWidthAccessor.ConsoleWidthProperty, Containable, CopyrightAccessor, CopyrightAccessor.CopyrightBuilder<ArgsParser>, CopyrightAccessor.CopyrightMutator, CopyrightAccessor.CopyrightProperty, DelimiterAccessor, DescriptionAccessor, DescriptionAccessor.DescriptionBuilder<ArgsParser>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionProperty, DescriptionEscapeCodeAccessor, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<ArgsParser>, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeProperty, Diagnosable, EmptyAccessor, EscapeCodesStatusAccessor, EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<ArgsParser>, EscapeCodesStatusAccessor.EscapeCodeStatusMutator, EscapeCodesStatusAccessor.EscapeCodeStatusProperty, ExamplesAccessor, ExamplesAccessor.ExamplesBuilder<ArgsParser>, ExamplesAccessor.ExamplesMutator, ExamplesAccessor.ExamplesProperty, ImmutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutableProperties, ImmutableTable<String,String>, Keys<String, String>, KeywordEscapeCodeAccessor, KeywordEscapeCodeAccessor.KeywordEscapeCodeBuilder<ArgsParser>, KeywordEscapeCodeAccessor.KeywordEscapeCodeMutator, KeywordEscapeCodeAccessor.KeywordEscapeCodeProperty, LicenseAccessor, LicenseAccessor.LicenseBuilder<ArgsParser>, LicenseAccessor.LicenseMutator, LicenseAccessor.LicenseProperty, LineBreakAccessor, LineBreakAccessor.LineBreakBuilder<ArgsParser>, LineBreakAccessor.LineBreakMutator, LineBreakAccessor.LineBreakProperty, LineSeparatorEscapeCodeAccessor, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<ArgsParser>, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeMutator, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeProperty, LongOptionPrefixAccessor, LongOptionPrefixAccessor.LongOptionPrefixBuilder<ArgsParser>, LongOptionPrefixAccessor.LongOptionPrefixMutator, LongOptionPrefixAccessor.LongOptionPrefixProperty, MaxConsoleWidthAccessor, MaxConsoleWidthAccessor.MaxConsoleWidthBuilder<ArgsParser>, MaxConsoleWidthAccessor.MaxConsoleWidthMutator, MaxConsoleWidthAccessor.MaxConsoleWidthProperty, NameAccessor, NameAccessor.NameBuilder<ArgsParser>, NameAccessor.NameMutator, NameAccessor.NameProperty, Optionable, Resetable, ResetEscapeCodeAccessor, ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<ArgsParser>, ResetEscapeCodeAccessor.ResetEscapeCodeMutator, ResetEscapeCodeAccessor.ResetEscapeCodeProperty, Schemable<DiagnosticOptions>, ShortOptionPrefixAccessor, ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<ArgsParser>, ShortOptionPrefixAccessor.ShortOptionPrefixMutator, ShortOptionPrefixAccessor.ShortOptionPrefixProperty, SyntaxMetricsAccessor, SyntaxMetricsAccessor.SyntaxMetricsBuilder<ArgsParser>, SyntaxMetricsAccessor.SyntaxMetricsMutator, SyntaxMetricsAccessor.SyntaxMetricsProperty, TextBoxGridAccessor, TextBoxGridAccessor.TextBoxGridBuilder<ArgsParser>, TextBoxGridAccessor.TextBoxGridMutator, TextBoxGridAccessor.TextBoxGridProperty, TitleAccessor, TitleAccessor.TitleBuilder<ArgsParser>, TitleAccessor.TitleMutator, TitleAccessor.TitleProperty, TypeAccessor<String>
- All Known Implementing Classes:
CliArgsParserProperties
The
ArgsParserProperties represent ImmutableProperties
generated from command line arguments being parsed by a command line syntax
as of the definition for the ArgsParser.-
Nested Class Summary
Nested classes/interfaces inherited from interface AnnotatorAccessor
AnnotatorAccessor.AnnotatorBuilder<B>, AnnotatorAccessor.AnnotatorMutator, AnnotatorAccessor.AnnotatorPropertyNested classes/interfaces inherited from interface ArgsSyntaxAccessor
ArgsSyntaxAccessor.ArgsSyntaxBuilder<B>, ArgsSyntaxAccessor.ArgsSyntaxMutator, ArgsSyntaxAccessor.ArgsSyntaxPropertyNested classes/interfaces inherited from interface ArgumentEscapeCodeAccessor
ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<B>, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator, ArgumentEscapeCodeAccessor.ArgumentEscapeCodePropertyNested classes/interfaces inherited from interface BannerBorderEscapeCodeAccessor
BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<B>, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodePropertyNested classes/interfaces inherited from interface BannerEscapeCodeAccessor
BannerEscapeCodeAccessor.BannerEscapeCodeBuilder<B>, BannerEscapeCodeAccessor.BannerEscapeCodeMutator, BannerEscapeCodeAccessor.BannerEscapeCodePropertyNested classes/interfaces inherited from interface BannerFontAccessor
BannerFontAccessor.BannerFontBuilder<B>, BannerFontAccessor.BannerFontMutator, BannerFontAccessor.BannerFontPropertyNested classes/interfaces inherited from interface BannerFontPaletteAccessor
BannerFontPaletteAccessor.BannerFontPaletteBuilder<B>, BannerFontPaletteAccessor.BannerFontPaletteMutator, BannerFontPaletteAccessor.BannerFontPalettePropertyNested classes/interfaces inherited from interface CommandEscapeCodeAccessor
CommandEscapeCodeAccessor.CommandEscapeCodeBuilder<B>, CommandEscapeCodeAccessor.CommandEscapeCodeMutator, CommandEscapeCodeAccessor.CommandEscapeCodePropertyNested classes/interfaces inherited from interface ConsoleWidthAccessor
ConsoleWidthAccessor.ConsoleWidthBuilder<B>, ConsoleWidthAccessor.ConsoleWidthMutator, ConsoleWidthAccessor.ConsoleWidthPropertyNested classes/interfaces inherited from interface CopyrightAccessor
CopyrightAccessor.CopyrightBuilder<B>, CopyrightAccessor.CopyrightMutator, CopyrightAccessor.CopyrightPropertyNested classes/interfaces inherited from interface DelimiterAccessor
DelimiterAccessor.DelimiterBuilder<B>, DelimiterAccessor.DelimiterMutator, DelimiterAccessor.DelimiterPropertyNested classes/interfaces inherited from interface DescriptionAccessor
DescriptionAccessor.DescriptionBuilder<B>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface DescriptionEscapeCodeAccessor
DescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<B>, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator, DescriptionEscapeCodeAccessor.DescriptionEscapeCodePropertyNested classes/interfaces inherited from interface EmptyAccessor
EmptyAccessor.EmptyBuilder<B>, EmptyAccessor.EmptyMutator, EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface EscapeCodesStatusAccessor
EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<B>, EscapeCodesStatusAccessor.EscapeCodeStatusMutator, EscapeCodesStatusAccessor.EscapeCodeStatusPropertyNested classes/interfaces inherited from interface ExamplesAccessor
ExamplesAccessor.ExamplesBuilder<B>, ExamplesAccessor.ExamplesMutator, ExamplesAccessor.ExamplesPropertyNested classes/interfaces inherited from interface ImmutableCanonicalTable
ImmutableCanonicalTable.MutableCanonicalTableNested classes/interfaces inherited from interface ImmutableInterOperableTable
ImmutableInterOperableTable.MutableInterOperableTable<T>Nested classes/interfaces inherited from interface ImmutablePathTable
ImmutablePathTable.MutablePathTable<T>Nested classes/interfaces inherited from interface ImmutableProperties
ImmutableProperties.MutablePropertiesNested classes/interfaces inherited from interface ImmutableTable
ImmutableTable.MutableTable<K,V> Nested classes/interfaces inherited from interface Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface KeywordEscapeCodeAccessor
KeywordEscapeCodeAccessor.KeywordEscapeCodeBuilder<B>, KeywordEscapeCodeAccessor.KeywordEscapeCodeMutator, KeywordEscapeCodeAccessor.KeywordEscapeCodePropertyNested classes/interfaces inherited from interface LicenseAccessor
LicenseAccessor.LicenseBuilder<B>, LicenseAccessor.LicenseMutator, LicenseAccessor.LicensePropertyNested classes/interfaces inherited from interface LineBreakAccessor
LineBreakAccessor.LineBreakBuilder<B>, LineBreakAccessor.LineBreakMutator, LineBreakAccessor.LineBreakPropertyNested classes/interfaces inherited from interface LineSeparatorEscapeCodeAccessor
LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<B>, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeMutator, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodePropertyNested classes/interfaces inherited from interface LongOptionPrefixAccessor
LongOptionPrefixAccessor.LongOptionPrefixBuilder<B>, LongOptionPrefixAccessor.LongOptionPrefixMutator, LongOptionPrefixAccessor.LongOptionPrefixPropertyNested classes/interfaces inherited from interface MaxConsoleWidthAccessor
MaxConsoleWidthAccessor.MaxConsoleWidthBuilder<B>, MaxConsoleWidthAccessor.MaxConsoleWidthMutator, MaxConsoleWidthAccessor.MaxConsoleWidthPropertyNested classes/interfaces inherited from interface NameAccessor
NameAccessor.NameBuilder<B>, NameAccessor.NameMutator, NameAccessor.NamePropertyNested classes/interfaces inherited from interface ResetEscapeCodeAccessor
ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<B>, ResetEscapeCodeAccessor.ResetEscapeCodeMutator, ResetEscapeCodeAccessor.ResetEscapeCodePropertyNested classes/interfaces inherited from interface ShortOptionPrefixAccessor
ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<B>, ShortOptionPrefixAccessor.ShortOptionPrefixMutator, ShortOptionPrefixAccessor.ShortOptionPrefixPropertyNested classes/interfaces inherited from interface SyntaxMetricsAccessor
SyntaxMetricsAccessor.SyntaxMetricsBuilder<B>, SyntaxMetricsAccessor.SyntaxMetricsMutator, SyntaxMetricsAccessor.SyntaxMetricsPropertyNested classes/interfaces inherited from interface TextBoxGridAccessor
TextBoxGridAccessor.TextBoxGridBuilder<B>, TextBoxGridAccessor.TextBoxGridMutator, TextBoxGridAccessor.TextBoxGridPropertyNested classes/interfaces inherited from interface TitleAccessor
TitleAccessor.TitleBuilder<B>, TitleAccessor.TitleMutator, TitleAccessor.TitlePropertyNested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> -
Field Summary
Fields inherited from interface ImmutablePathTable
ANNOTATOR, DELIMITERFields inherited from interface ImmutableProperties
DEFAULT_COMMENT -
Method Summary
Modifier and TypeMethodDescriptionOperand<?>[]Evaluates the command line arguments and sets the identified properties in thisImmutablePropertiesinstance.Operand<?>[]Same asevalArgs(String[])with the difference that the identified properties are inserted below the provided path.Operand<?>[]Same asevalArgs(String[])with the difference that the identified properties are inserted below the provided path.Operand<?>[]Evaluates the command line arguments and sets the identified properties in thisImmutablePropertiesinstance.default ArgsParserPropertieswithEvalArgs(String[] aArgs) Same asevalArgs(String[])with the difference that this class's instance being invoked is returned as of the builder pattern.default ArgsParserPropertieswithEvalArgs(String aToPath, String[] aArgs) Same asevalArgs(String[])with the difference that the identified properties are inserted below the provided path and that this class's instance being invoked is returned as of the builder pattern.default ArgsParserPropertieswithEvalArgs(String aToPath, List<String> aArgs) Same asevalArgs(String[])with the difference that the identified properties are inserted below the provided path and that this class's instance being invoked is returned as of the builder pattern.default ArgsParserPropertieswithEvalArgs(List<String> aArgs) Same asevalArgs(List)with the difference that this class's instance being invoked is returned as of the builder pattern.Methods inherited from interface ArgsParser
addExample, addExample, errorLn, evalArgs, evalArgs, evalArgs, evalArgs, getArgsSyntax, getArgumentEscapeCode, getBannerBorderEscapeCode, getBannerEscapeCode, getCommandEscapeCode, getCopyright, getDescription, getDescriptionEscapeCode, getExamples, getKeywordEscapeCode, getLicense, getLineSeparatorEscapeCode, getSeparatorLnChar, printBanner, printBody, printCopyright, printDescription, printExamples, printHeader, printHelp, printLicense, printLn, printLn, printOptions, printSeparatorLn, printSynopsis, setErrorOut, setLineSeparatorEscapeCode, setSeparatorLnChar, setStandardOut, setSyntaxMetrics, toOptions, toSchema, withAddExample, withAddExample, withArgumentEscapeCode, withBannerBorderEscapeCode, withBannerEscapeCode, withBannerFont, withBannerFontPalette, withCommandEscapeCode, withConsoleWidth, withCopyright, withDescription, withDescriptionEscapeCode, withErrorOut, withEscapeCodesEnabled, withExamples, withExamples, withKeywordEscapeCode, withLicense, withLineBreak, withLineSeparatorEscapeCode, withLongOptionPrefix, withMaxConsoleWidth, withName, withResetEscapeCode, withSeparatorLnChar, withShortOptionPrefix, withStandardOut, withSyntaxMetrics, withTextBoxGrid, withTextBoxGrid, withTitleMethods inherited from interface ArgsParserBuilder
withEvalArgs, withEvalArgs, withEvalArgs, withEvalArgsMethods inherited from interface ArgsSyntaxAccessor.ArgsSyntaxBuilder
withArgsSyntaxMethods inherited from interface ArgsSyntaxAccessor.ArgsSyntaxMutator
setArgsSyntaxMethods inherited from interface ArgsSyntaxAccessor.ArgsSyntaxProperty
letArgsSyntaxMethods inherited from interface ArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator
setArgumentEscapeCodeMethods inherited from interface ArgumentEscapeCodeAccessor.ArgumentEscapeCodeProperty
letArgumentEscapeCodeMethods inherited from interface BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator
setBannerBorderEscapeCodeMethods inherited from interface BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeProperty
letBannerBorderEscapeCodeMethods inherited from interface BannerEscapeCodeAccessor.BannerEscapeCodeMutator
setBannerEscapeCodeMethods inherited from interface BannerEscapeCodeAccessor.BannerEscapeCodeProperty
letBannerEscapeCodeMethods inherited from interface BannerFontAccessor
getBannerFontMethods inherited from interface BannerFontAccessor.BannerFontMutator
setBannerFontMethods inherited from interface BannerFontAccessor.BannerFontProperty
letBannerFontMethods inherited from interface BannerFontPaletteAccessor
getBannerFontPaletteMethods inherited from interface BannerFontPaletteAccessor.BannerFontPaletteBuilder
withBannerFontPaletteMethods inherited from interface BannerFontPaletteAccessor.BannerFontPaletteMutator
setBannerFontPalette, setBannerFontPaletteMethods inherited from interface BannerFontPaletteAccessor.BannerFontPaletteProperty
letBannerFontPaletteMethods inherited from interface CommandEscapeCodeAccessor.CommandEscapeCodeMutator
setCommandEscapeCodeMethods inherited from interface CommandEscapeCodeAccessor.CommandEscapeCodeProperty
letCommandEscapeCodeMethods inherited from interface ConsoleWidthAccessor
getConsoleWidthMethods inherited from interface ConsoleWidthAccessor.ConsoleWidthMutator
setConsoleWidthMethods inherited from interface ConsoleWidthAccessor.ConsoleWidthProperty
letConsoleWidthMethods inherited from interface Containable
sizeMethods inherited from interface CopyrightAccessor.CopyrightMutator
setCopyrightMethods inherited from interface CopyrightAccessor.CopyrightProperty
letCopyrightMethods inherited from interface DescriptionAccessor.DescriptionMutator
setDescriptionMethods inherited from interface DescriptionAccessor.DescriptionProperty
letDescriptionMethods inherited from interface DescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator
setDescriptionEscapeCodeMethods inherited from interface DescriptionEscapeCodeAccessor.DescriptionEscapeCodeProperty
letDescriptionEscapeCodeMethods inherited from interface EmptyAccessor
isEmptyMethods inherited from interface EscapeCodesStatusAccessor
isEscapeCodesEnabledMethods inherited from interface EscapeCodesStatusAccessor.EscapeCodeStatusMutator
setEscapeCodesEnabledMethods inherited from interface EscapeCodesStatusAccessor.EscapeCodeStatusProperty
letEscapeCodesEnabledMethods inherited from interface ExamplesAccessor.ExamplesMutator
setExamples, setExamplesMethods inherited from interface ExamplesAccessor.ExamplesProperty
letExamplesMethods inherited from interface ImmutableCanonicalTable
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, queryBetween, toMap, toPropertiesMethods inherited from interface ImmutableInterOperableTable
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOrMethods inherited from interface ImmutablePathTable
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPrintable, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toTypeMethods inherited from interface ImmutableProperties
containsValue, getAnnotator, getDelimiter, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, getType, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, retrieveToMethods inherited from interface KeywordEscapeCodeAccessor.KeywordEscapeCodeMutator
setKeywordEscapeCodeMethods inherited from interface KeywordEscapeCodeAccessor.KeywordEscapeCodeProperty
letKeywordEscapeCodeMethods inherited from interface LicenseAccessor.LicenseMutator
setLicenseMethods inherited from interface LicenseAccessor.LicenseProperty
letLicenseMethods inherited from interface LineBreakAccessor
getLineBreakMethods inherited from interface LineBreakAccessor.LineBreakMutator
setLineBreakMethods inherited from interface LineBreakAccessor.LineBreakProperty
letLineBreakMethods inherited from interface LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeProperty
letLineSeparatorEscapeCodeMethods inherited from interface LongOptionPrefixAccessor
getLongOptionPrefixMethods inherited from interface LongOptionPrefixAccessor.LongOptionPrefixMutator
setLongOptionPrefixMethods inherited from interface LongOptionPrefixAccessor.LongOptionPrefixProperty
letLongOptionPrefixMethods inherited from interface MaxConsoleWidthAccessor
getMaxConsoleWidthMethods inherited from interface MaxConsoleWidthAccessor.MaxConsoleWidthMutator
setMaxConsoleWidthMethods inherited from interface MaxConsoleWidthAccessor.MaxConsoleWidthProperty
letMaxConsoleWidthMethods inherited from interface NameAccessor
getNameMethods inherited from interface NameAccessor.NameMutator
setNameMethods inherited from interface NameAccessor.NameProperty
letNameMethods inherited from interface ResetEscapeCodeAccessor
getResetEscapeCodeMethods inherited from interface ResetEscapeCodeAccessor.ResetEscapeCodeMutator
setResetEscapeCodeMethods inherited from interface ResetEscapeCodeAccessor.ResetEscapeCodeProperty
letResetEscapeCodeMethods inherited from interface ShortOptionPrefixAccessor
getShortOptionPrefixMethods inherited from interface ShortOptionPrefixAccessor.ShortOptionPrefixMutator
setShortOptionPrefixMethods inherited from interface ShortOptionPrefixAccessor.ShortOptionPrefixProperty
letShortOptionPrefixMethods inherited from interface SyntaxMetricsAccessor
getSyntaxMetricsMethods inherited from interface SyntaxMetricsAccessor.SyntaxMetricsBuilder
withSyntaxMetricsMethods inherited from interface SyntaxMetricsAccessor.SyntaxMetricsMutator
setSyntaxMetricsMethods inherited from interface SyntaxMetricsAccessor.SyntaxMetricsProperty
letSyntaxMetrics, letSyntaxMetricsMethods inherited from interface TextBoxGridAccessor
getTextBoxGridMethods inherited from interface TextBoxGridAccessor.TextBoxGridMutator
setTextBoxGrid, setTextBoxGridMethods inherited from interface TextBoxGridAccessor.TextBoxGridProperty
letTextBoxGrid, letTextBoxGridMethods inherited from interface TitleAccessor
getTitleMethods inherited from interface TitleAccessor.TitleMutator
setTitleMethods inherited from interface TitleAccessor.TitleProperty
letTitle
-
Method Details
-
evalArgs
Evaluates the command line arguments and sets the identified properties in thisImmutablePropertiesinstance. Previously identified properties are reset upon invocation of this method. When provided, then anOperand's alias is used as property name, else as fall back, the operand's (when being of sub-typeOption) long-option or short-option is used. Make sure, to provide an alias to make theImmutablePropertieswork and feel as intended!- Specified by:
evalArgsin interfaceArgsParser- Throws:
ArgsSyntaxException
-
evalArgs
Evaluates the command line arguments and sets the identified properties in thisImmutablePropertiesinstance. Previously identified properties are reset upon invocation of this method. When provided, then anOperand's alias is used as property name, else as fall back, the operand's (when being of sub-typeOption) long-option or short-option is used. Make sure, to provide an alias to make theImmutablePropertieswork and feel as intended!- Specified by:
evalArgsin interfaceArgsParser- Throws:
ArgsSyntaxException
-
evalArgs
Same asevalArgs(String[])with the difference that the identified properties are inserted below the provided path.- Parameters:
aToPath- The path below which to insert the identified properties.aArgs- The command line arguments to be evaluated.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
evalArgs
Same asevalArgs(String[])with the difference that the identified properties are inserted below the provided path.- Parameters:
aToPath- The path below which to insert the identified properties.aArgs- The command line arguments to be evaluated.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withEvalArgs
Same asevalArgs(String[])with the difference that this class's instance being invoked is returned as of the builder pattern.- Specified by:
withEvalArgsin interfaceArgsParser- Specified by:
withEvalArgsin interfaceArgsParserBuilder<ArgsParser>- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- This invoked instance as of the builder pattern to chain method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withEvalArgs
Same asevalArgs(List)with the difference that this class's instance being invoked is returned as of the builder pattern.- Specified by:
withEvalArgsin interfaceArgsParser- Specified by:
withEvalArgsin interfaceArgsParserBuilder<ArgsParser>- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- This invoked instance as of the builder pattern to chain method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withEvalArgs
default ArgsParserProperties withEvalArgs(String aToPath, List<String> aArgs) throws ArgsSyntaxException Same asevalArgs(String[])with the difference that the identified properties are inserted below the provided path and that this class's instance being invoked is returned as of the builder pattern.- Parameters:
aToPath- The path below which to insert the identified properties.aArgs- The command line arguments to be evaluated.- Returns:
- This invoked instance as of the builder pattern to chain method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withEvalArgs
default ArgsParserProperties withEvalArgs(String aToPath, String[] aArgs) throws ArgsSyntaxException Same asevalArgs(String[])with the difference that the identified properties are inserted below the provided path and that this class's instance being invoked is returned as of the builder pattern.- Parameters:
aToPath- The path below which to insert the identified properties.aArgs- The command line arguments to be evaluated.- Returns:
- This invoked instance as of the builder pattern to chain method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-