Package org.refcodes.properties.ext.cli
-
Interface Summary Interface Description ArgsParserProperties TheArgsParserPropertiesrepresentPropertiesgenerated from command line arguments being parsed by a command line syntax as of the definition for theArgsParser.ArgsParserPropertiesAccessor Provides an accessor for aArgsParserPropertiesproperty.ArgsParserPropertiesAccessor.ArgsParserPropertiesBuilder<B extends ArgsParserPropertiesAccessor.ArgsParserPropertiesBuilder<B>> Provides a builder method for aArgsParserPropertiesproperty returning the builder for applying multiple build operations.ArgsParserPropertiesAccessor.ArgsParserPropertiesMutator Provides a mutator for aArgsParserPropertiesproperty.ArgsParserPropertiesAccessor.ArgsParserPropertiesProperty Provides aArgsParserPropertiesproperty. -
Class Summary Class Description ArgsParserPropertiesImpl