Uses of Package
org.refcodes.properties.ext.cli
-
Classes in org.refcodes.properties.ext.cli used by org.refcodes.properties.ext.cliClassDescriptionThe
ArgsParserPropertiesclass implements theParseArgsPropertiestype to combine theParseArgstype with thePropertiestype in a dedicated class.Provides an accessor for aParseArgsPropertiesproperty.Provides a builder method for aParseArgsPropertiesproperty returning the builder for applying multiple build operations.Provides a mutator for aParseArgsPropertiesproperty.TheParseArgsPropertiesrepresentPropertiesgenerated from command line arguments being parsed by a command line syntax as of the definition for theParseArgs.